import requests
from .statics import BASEURL, Notification

class Account():

    def __init__(self, BearerToken:str):
        self.BearerToken = BearerToken  

    @property
    def wallet(self) -> tuple[int, int]:
        """
            Retorna uma tupla com o valor líquido e o bruto da carteira, respectivamente
        """
        response = requests.get(
            f'{BASEURL}/account/wallet',
            headers={'Authorization': self.BearerToken}
        )
        if response.status_code == 200:
            data = response.json()
            return (data["amount"], data["grossAmount"])
        else:
            raise Exception(f'Request returned status {response.status_code} | Response: {response.text}')
    
    @property
    def notifications(self) -> list[Notification]:
        response = requests.get(
            f'{BASEURL}/account/notifications',
            headers={'Authorization': self.BearerToken}
        )
        if response.status_code == 200:
            return [Notification(notification) for notification in response.json()['data']]
        else:
            raise Exception(f'Request returned status {response.status_code} | Response: {response.text}')


MINIMUM_VALUE = 100
BASEURL = "https://alertpix.fly.dev"


class Notification:
    def __init__(self, json:dict):
        self.json = json
        self.type = json["type"]
        self.message = json["message"]
        self.seen:bool = json["seen"]
        self.createdAt:int = json["createdAt"]
        if json.get('metadata'):
            class Metadata:
                def __init__(self, json:dict):
                    self.amount = json['metadata']['amount']
                    self.grossAmount = json['metadata']['grossAmount']
                    self.audio:bool = json['metadata']['audio']
                    self.comment = json['metadata']['comment']
                    self.username = json['metadata']['userName']

            self.metadata = Metadata(json)

        return


import requests
from .brcode import BrCODE
from .statics import BASEURL
class Charge():
    def __init__(self, link:str,  amount:int, comment:str=".", username:str=None,) -> None:
        """
        Args:x'
            link (str): Username da conta da twitch que IRÁ RECEBER
            comment (str): Mensagem que o usuário irá receber (OPCIONAL)
            username (str): Nome que o pagante será identificado (OPCIONAL)
            amount (int): Quantia que o usuário irá receber
        """
        if amount <= 100:
            raise ValueError("Amount must be greater than 100")
        self.link = link
        self.comment = comment
        self.username = username
        self.amount = amount

    def create(self):
        request  =  requests.post(
            url=f'{BASEURL}/create-charge',
            json={
                "link": self.link,
                "amount": self.amount,
                "comment": self.comment,
                "userName": self.username,
                "anonymous": True if self.username == None else False

            },
            headers={"content-type": "application/json"}
            
        )
        if request.status_code == 200:
            self.charge_id = request.json()['data']["id"]
            self.brcode = BrCODE(request.json()['data']["brCode"])   
            return self
        else:
            raise Exception(f'Request returned status {request.status_code} | Response: {request.text}')

    def check(self) -> bool:
        """
        Verifica se o pagamento foi concluído

        Retorna:
            bool: True se o pagamento foi concluído, False se não
        """
        request  =  requests.get(
            url=f'{BASEURL}/check-charge?id={self.charge_id}'
        )
        if request.status_code == 200:
            return False if request.json()["data"]["status"] == "pending" else True
        else:
            raise Exception(f'Request returned status {request.status_code} | Response: {request.text}')


#!/usr/bin/python
# -*- coding: utf-8 -*-

import setuptools

with open("README.md", "r", encoding="UTF-8") as fh:
    long_description = fh.read()

requirements = [
    "qrcode",
    "requests"
]

setuptools.setup(
    name="alertpix",
    version="0.3.6",
    author="Joaquim Cassano",
    license='MIT',
    author_email="joaquim@cassano.com.br",
    description='Python library for communication with the alertpix api',
    long_description=long_description,
    long_description_content_type="text/markdown",
    install_requires=requirements,
    keywords=["api", "alertpix", "payments", "pix"],
    url="https://github.com/JoaquimCassano/Alertpix.py",
    packages=["alertpix", "alertpix.src"],
    package_dir={"alertpix": "alertpix", "alertpix.src": "alertpix/src"},
    python_requires=">=3.7",
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)